## Pull Requests

We welcome pull requests.

1. Fork the repo and create your branch from `develop`, we are using the git flow branching model.
2. If you've added code that should be tested, add tests.
3. If you've changed APIs, update the documentation.

## Issues

We use GitHub issues to track public bugs. Please ensure your description is clear and has sufficient instructions to be able to reproduce the issue.

## Coding Style

...

## License

By contributing to [Draugr](https://github.com/cnheider/draugr), you agree that your contributions will be licensed under the LICENSE file in the root directory of this repository.
